/*
 * File:    Opravna.java
 * Package: dm.vpi.lekce05.vozidla1
 * Project: Lekce05
 * 
 * Author : David Martinek
 * Address: Department of Intelligent Systems
 *          Faculty of Information Technology
 *          Brno University of Technology
 *          Bozetechova 2, 
 *          612 66 Brno, 
 *          Czech Republic
 * E-mail : martinek@fit.vutbr.cz
 * 
 * Created on 3.4.2005
 * (c) 2005, David Martinek
 * 
 * This project is provided under conditions of GNU General Public Licence.
 * The full text of GNU GPL in on internet: http://www.gnu.org/licenses/gpl.html
 * 
 * $Id$
 */
package dm.vpi.lekce05.vozidla1;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * Tda reprezentujc opravnu automobil.
 * 
 * @author David Martinek
 */
public class Opravna
{
  /**
   * Maximln kapacita opravny.
   */
  protected int kapacita;

  /**
   * Seznam mst v opravn.
   */
  protected List mista;


  /**
   * Vytvo novou opravnu o zadan kapacit.
   * 
   * @param kapacita
   *          Maximln kapacita opravny.
   */
  public Opravna(int kapacita)
  {
    mista = new ArrayList(kapacita);
    this.kapacita = kapacita;
  }

  /**
   * Pjem vozidla do opravny.
   * 
   * @param v
   *          Pijman vozidlo.
   * @return Vrac true, pokud bylo v opravn dostatek msta a false, pokud
   *         bylo vozidlo odmtnuto.
   */
  public boolean prijem(Vozidlo v)
  {
    if (mista.size() >= kapacita)
      return false;
    mista.add(v);
    return true;
  }

  /**
   * Pjem vozidla do opravny s poadavkem na pelakovn vozidla. Metoda
   * prijem je peten.
   * 
   * @param v
   *          Pijman vozidlo.
   * @param novaBarva
   *          Barva, na kterou m bt vozidlo pelakovno.
   * @return Vrac true, pokud bylo v opravn dostatek msta a false, pokud
   *         bylo vozidlo odmtnuto.
   */
  public boolean prijem(Vozidlo v, Barva novaBarva)
  {
    if (prijem(v))
    {
      v.setBarva(novaBarva);
      return true;
    }
    return false;
  }

  /**
   * Vdej opravenho vozidla podle zadan poznvac znaky.
   * 
   * @param spz
   *          Poznvac znaka vydvanho vozidla.
   * @return Vrac vozidlo se zadanou poznvac znakou. Pokud vozidlo s
   *         touto znakou v opravn nen, vrac null.
   */
  public Vozidlo vydej(String spz)
  {
    for (Iterator iter = mista.iterator(); iter.hasNext();)
    {
      Vozidlo v = (Vozidlo) iter.next();
      if (v.getSpz().equals(spz))
      {
        iter.remove(); // odstran vozidlo ze seznamu
        return v;
      }
    }
    return null;
  }

  /**
   * Vytiskne daje o vech vozidlech v opravn.
   */
  public void tiskniUdaje()
  {
    for (Iterator iter = mista.iterator(); iter.hasNext();)
    {
      Vozidlo v = (Vozidlo) iter.next();
      v.tiskniZaznam();
    }
  }

  public static void main(String[] args)
  {
    Opravna opravna = new Opravna(4);
    opravna.prijem(new Auto("Trabant", "JB007", Barva.CERNA, 200, 130));
    opravna.prijem(new Motocykl("Yamaha", "1B2 3028", Barva.ZLUTA, false));
    opravna.prijem(new Motocykl("Babeta", "b001", Barva.ZELENA, true),
        Barva.BILA);

    System.out.println("V opravn:");
    opravna.tiskniUdaje();

    System.out.println();
    System.out.println("Chci vrtit vozidlo s spz \"1B2 3028\"");
    Vozidlo v = opravna.vydej("1B2 3028");
    System.out.println("Vrceno:");
    if (v != null)
      v.tiskniZaznam();
    else
      System.out.println("Vozidlo nenalezeno!");

    System.out.println();
    System.out.println("Chci vrtit vozidlo s spz \"KIA 07 23\"");
    v = opravna.vydej("KIA 07 23");
    System.out.println("Vrceno:");
    if (v != null)
      v.tiskniZaznam();
    else
      System.out.println("Vozidlo nenalezeno!");

    System.out.println();
    System.out.println("V oprav:");
    opravna.tiskniUdaje();
  }
}

// end of file Garaz.java
