/*
 * File:    Vozidlo.java
 * Package: dm.vpi.lekce05.vozidla1
 * Project: Lekce05
 * 
 * Author : David Martinek
 * Address: Department of Intelligent Systems
 *          Faculty of Information Technology
 *          Brno University of Technology
 *          Bozetechova 2, 
 *          612 66 Brno, 
 *          Czech Republic
 * E-mail : martinek@fit.vutbr.cz
 * 
 * Created on 3.4.2005
 * (c) 2005, David Martinek
 * 
 * This project is provided under conditions of GNU General Public Licence.
 * The full text of GNU GPL in on internet: http://www.gnu.org/licenses/gpl.html
 * 
 * $Id$
 */
package dm.vpi.lekce05.vozidla1;

/**
 * Tda popisujc obecn automobil.
 * <p>
 * Tato tda demonstruje zkladn vlastnost objektov orientovanch
 * jazyk: <i>zapouzdenost</i>. Tda zapouzduje datov poloky (zde
 * data popisujc automobil - typ, barva, SPZ) a operace, kter lze nad
 * tmito daty vykonvat.
 * </p>
 * 
 * @author David Martinek
 */
public abstract class Vozidlo
{
  
  /**
   * Typov oznaen vozidla.
   */
  protected String typ;

  /**
   * Sttn poznvac znaka.
   */
  protected String spz;

  /**
   * Barva auta.
   */
  protected Barva barva;


  /**
   * Vytvo zznam o aut zadanho typu, barvy a s konkrtn poznvac
   * znakou.
   * 
   * @param typ
   *          Typov oznaen auta.
   * @param spz
   *          Sttn poznvac znaka.
   * @param barva
   *          Barva automobilu.
   */
  public Vozidlo(String typ, String spz, Barva barva)
  {
    this.typ = typ;
    this.spz = spz;
    this.barva = barva;
  }

  /**
   * @return Vrac barvu auta.
   */
  public Barva getBarva()
  {
    return barva;
  }

  /**
   * Nastav barvu automobilu
   * 
   * @param barva
   *          Barva automobilu.
   */
  public void setBarva(Barva barva)
  {
    this.barva = barva;
  }

  /**
   * @return Vrac sttn poznvac znaku.
   */
  public String getSpz()
  {
    return spz;
  }

  /**
   * @return Vrac znaku auta (BMW, Trabant, ...).
   */
  public String getTyp()
  {
    return typ;
  }

  /**
   * Vytiskne na stdout daje o tomto vozidle.
   */
  public void tiskniZaznam()
  {
    // zde se this vlastn nahrad za this.toString
    System.out.println(this);
  }

  /**
   * Vrt textovou reprezentaci objektu. Tato metoda pekrv metodu pedka
   * (Object).
   * 
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    // Pro spojovn vtho mnostv kousk etzc je lep pout 
    // StringBuilder (pro Javu >= 5) nebo StringBuffer. Je to mnohem 
    // nkolikansobn efektivnj ne prost stn etzc.
    StringBuilder string = new StringBuilder("Typ: ");
    string.append(typ);
    string.append(", Barva: ");
    string.append(barva);
    string.append(", SPZ: ");
    string.append(spz);
    return string.toString();    
  }

  /**
   * Porovn dv vozidla. Tato operace mus bt reflexivn, tranzitivn a 
   * symetrick. Tato metoda pekrv metodu pedka (Object).
   * 
   * @see java.lang.Object#equals(java.lang.Object)
   */
  public boolean equals(Object obj)
  {
    // opertor instanceof zjist, zda je reference kompatibiln se zadanou
    // tdou
    if ( !(obj instanceof Vozidlo))
      return false;
    // Petypovn
    Vozidlo car = (Vozidlo) obj;
    return car.typ.equals(this.typ) && car.spz.equals(this.spz)
        && car.barva.equals(this.barva);
  }
  
}

// end of file Vozidlo.java
